@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2010 Julien Jorge
+  Copyright (C) 2005-2011 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-  contact: julien_jorge@yahoo.fr
+  contact: julien.jorge@gamned.org
 */
 /**
  * \file pixel.cpp
@@ -29,7 +29,12 @@
  */
 #include <claw/pixel.hpp>
 
+#include <claw/types.hpp>
+
+#include <stdexcept>
 #include <limits>
+#include <climits>
+#include <sstream>
 
 namespace claw
 {
@@ -107,6 +112,27 @@ claw::graphic::rgb_pixel::rgb_pixel( const rgba_pixel& p )
   components.blue = p.components.blue;
 } // rgb_pixel::rgb_pixel()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Constructor from a color name or code.
+ * \param c The color name or code.
+ */
+claw::graphic::rgb_pixel::rgb_pixel( const std::string& c )
+{
+  std::istringstream iss(c);
+  u_int_32 color;
+
+  if ( c[0] == '#' )
+    iss.ignore(1);
+
+  if ( !(iss >> std::hex >> color) )
+    throw std::invalid_argument(c);
+
+  components.red = (color & 0xFF0000) >> (CHAR_BIT * 2);
+  components.green = (color & 0x00FF00) >> CHAR_BIT;
+  components.blue = color & 0x0000FF;
+} // rgb_pixel::rgb_pixel()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Compare to a pixel.
@@ -192,6 +218,38 @@ claw::graphic::rgba_pixel::rgba_pixel
   components.alpha = a;
 } // rgba_pixel::rgba_pixel()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Constructor from a color name or code.
+ * \param c The color name or code.
+ */
+claw::graphic::rgba_pixel::rgba_pixel( const std::string& c )
+{
+  std::istringstream iss(c);
+  u_int_32 color;
+  bool has_alpha;
+
+  if ( c[0] == '#' )
+    {
+      iss.ignore(1);
+      has_alpha = c.length() > 7;
+    }
+  else
+    has_alpha = c.length() > 6;
+
+  if ( !((iss >> std::hex >> color) && (iss.rdbuf()->in_avail() == 0)) )
+    throw std::invalid_argument(c);
+
+  if ( has_alpha )
+    components.alpha = (color & 0xFF000000) >> (CHAR_BIT * 3);
+  else
+    components.alpha = std::numeric_limits<component_type>::max();
+
+  components.red = (color & 0xFF0000) >> (CHAR_BIT * 2);
+  components.green = (color & 0x00FF00) >> CHAR_BIT;
+  components.blue = color & 0x0000FF;
+} // rgba_pixel::rgba_pixel()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Assignement operator.
