@@ -5,7 +5,7 @@
   anyone.
 
   Copyright (C) 2005 Sébastien Angibaud
-  Copyright (C) 2005-2010 Julien Jorge
+  Copyright (C) 2005-2011 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,7 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-  contact: julien_jorge@yahoo.fr
+  contact: julien.jorge@gamned.org
 */
 /**
  * \file game_ai.hpp
